#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-1KEtXWoXP2hEbFrs5pMVDm
key:                  stack-2.9.3.1-1KEtXWoXP2hEbFrs5pMVDm
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  99920f24235277d2da5a122d8b8b40c7
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-1KEtXWoXP2hEbFrs5pMVDm
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-Hf6fFmjaIfCVZ3DoDW5HB array-0.5.6.0
    async-2.2.6-Cc2ylPSJ9T994nMR0Eaxyq
    attoparsec-0.14.4-DVQW3zaPrEjFLUvmkAZYCq base-4.18.2.1
    base64-bytestring-1.2.1.0-C0qMqvh3vbu1LTlZEUtx0r
    bytestring-0.11.5.3 casa-client-0.0.4-33OrgWWBz6O1tHcstVqNOz
    casa-types-0.0.3-7KIFaoxbpUN9Cef0s99eQS
    colour-2.3.7-xhIDZ6j0j1vTiLcOK4Oo
    conduit-1.3.6.1-KPHDCDDIHN1EOURpcrFXUe
    conduit-extra-1.3.8-1lTAw5MbR9d8jW8YQMIELA containers-0.6.7
    crypton-1.0.5-1z1P9gki3DpXKZxddhNPM
    crypton-conduit-0.2.3-ODRDZHeb8JCATwFUSq5lx deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-J2nH1si97LP2pkcRW1gnIU
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-2Ib8lnLgDCaLmHleGe7QaZ filepath-1.4.300.1
    fsnotify-0.4.4.0-JaJfLX6XQo061WoefvNGtv
    generic-deriving-1.14.7-E45zydjQUReE3T5FFRTnL4
    hackage-security-0.6.3.2-EkvQiShKg3h31dO6NGhMC0
    hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    hi-file-parser-0.1.8.0-HZz2ij2fmwXCd5QOR2aMsY
    hpack-0.38.0-yZ4ygwrGWAKpWN5z14rKP hpc-0.6.2.0
    http-client-0.7.19-uRvF7eEYhRDNuWEwLS8eA
    http-client-tls-0.3.6.4-4YRJdpyh0LQFEcqojHieFc
    http-conduit-2.3.9.1-3jVRXfysx7LHah4LOBTB7z
    http-download-0.2.1.0-AtUw3W26yo79o4cp8kNrdo
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-4cu4v49IGdXLeIxxHT3q3f mtl-2.3.1
    mustache-2.4.3.1-AgHvFLgnmqMJEDtyz4VVR1
    neat-interpolation-0.5.1.4-1N8x5uAr10K50vXpIYaWn2
    network-uri-2.6.4.2-HyBVnFdXLs0Dgiq4qkHmFH
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    pantry-0.8.3-5L2ARdIZqBbGLLKdztZ1Cw
    path-0.9.6-7raF4tLYHpHKU533QPH3ar
    path-io-1.8.2-LqVUKJgbNg24vWj2eLJlCU
    persistent-2.14.6.0-wrdZHt5R2XHggQJSqQSHD
    persistent-sqlite-2.13.3.0-7PpxFgx5O3694dfv2KiA5 pretty-1.1.3.6
    primitive-0.9.1.0-9K5vR1Mi21T8XGVzI2tm4J process-1.6.19.0
    project-template-0.2.1.0-8F4a8VRA40eJ22So88XJkd
    random-1.2.1.3-L4ByjUo9HMh9NaA0HunG5L
    retry-0.9.3.1-2yeM0AgITxv5jkUTX6ziOD
    rio-0.1.24.0-FcidF0Ma4YNv6HER3ssBf
    rio-prettyprint-0.1.9.0-SKWMyh0FZK92EnuYP4Vcp
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    streaming-commons-0.2.3.1-F39MgPe8hQUHravdDJCznZ
    tar-0.6.0.0-2AlYzEPApJf7TzoUIkXY6Y template-haskell-2.20.0.0
    temporary-1.3-6jR9Y0qK20e3lOLKCzgpYi text-2.0.2
    text-metrics-0.3.3-FGPBmpo5qec8F0jZAa41LA
    th-reify-many-0.1.10-6NgShOzGkITJFnJY11k7uH time-1.12.2
    tls-2.0.6-K01zBezmQ95F2zsJDeRM5g transformers-0.6.1.0
    typed-process-0.2.13.0-8swOl8qwZIo4tYHRa44umx
    unicode-transforms-0.4.0.1-DoCFgj22kGRFUACQiLBmPT unix-2.8.4.0
    unix-compat-0.7.4.1-31l13LRLjrjFWmUAAvgT92
    unliftio-0.2.25.1-5kFyykBV8QLAHqHdpZTooL
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    yaml-0.11.11.2-Gz9Bz4lbRgP2FR94qGDleq
    zip-archive-0.4.3.2-LMYqDQ0oUxCT9ZieCrqlA
    zlib-0.7.1.0-JUvXnJeECOb5UrlPGbJucV

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

